==> vplus-0.1.0-sources.jar: tech/nevets/vplus/blocks/SaturatedLavaSpongeBlock.java <==
package tech.nevets.vplus.blocks;

import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.fabricmc.fabric.api.object.builder.v1.block.FabricBlockSettings;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2398;
import net.minecraft.class_2498;
import net.minecraft.class_2680;
import net.minecraft.class_3614;
import java.util.Random;

public class SaturatedLavaSpongeBlock extends class_2248 {

    public SaturatedLavaSpongeBlock() {
        super(FabricBlockSettings.method_9637(class_3614.field_15914).method_9632(0.6F).method_9626(class_2498.field_22143));
    }

    @Environment(EnvType.CLIENT)
    public void method_9496(class_2680 state, class_1937 , class_2338 , Random ) {
        class_2350 direction = class_2350.method_10162();
        if (direction != class_2350.field_11036) {
            class_2338 blockPos = .method_10093(direction);
            class_2680 blockState = .method_8320(blockPos);
            if (!state.method_26225() || !blockState.method_26206(, blockPos, direction.method_10153())) {
                double d = (double).method_10263();
                double e = (double).method_10264();
                double f = (double).method_10260();
                if (direction == class_2350.field_11033) {
                    e -= 0.05D;
                    d += .nextDouble();
                    f += .nextDouble();
                } else {
                    e += .nextDouble() * 0.8D;
                    if (direction.method_10166() == class_2350.class_2351.field_11048) {
                        f += .nextDouble();
                        if (direction == class_2350.field_11034) {
                            ++d;
                        } else {
                            d += 0.05D;
                        }
                    } else {
                        d += .nextDouble();
                        if (direction == class_2350.field_11035) {
                            ++f;
                        } else {
                            f += 0.05D;
                        }
                    }
                }

                .method_8406(class_2398.field_11223, d, e, f, 0.0D, 0.0D, 0.0D);
            }
        }
    }

}

==> vplus-1.1.1-sources.jar: tech/nevets/vplus/blocks/SaturatedLavaSpongeBlock.java <==
package tech.nevets.vplus.blocks;

import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.fabricmc.fabric.api.object.builder.v1.block.FabricBlockSettings;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2398;
import net.minecraft.class_2498;
import net.minecraft.class_2680;
import net.minecraft.class_3614;
import java.util.Random;

public class SaturatedLavaSpongeBlock extends class_2248 {

    public SaturatedLavaSpongeBlock() {
        super(FabricBlockSettings.method_9637(class_3614.field_15914).method_9632(0.6F).method_9626(class_2498.field_22143));
    }

    @Environment(EnvType.CLIENT)
    public void method_9496(class_2680 state, class_1937 world, class_2338 pos, Random random) {
        class_2350 direction = class_2350.method_10162(random);
        if (direction != class_2350.field_11036) {
            class_2338 blockPos = pos.method_10093(direction);
            class_2680 blockState = world.method_8320(blockPos);
            if (!state.method_26225() || !blockState.method_26206(world, blockPos, direction.method_10153())) {
                double d = (double)pos.method_10263();
                double e = (double)pos.method_10264();
                double f = (double)pos.method_10260();
                if (direction == class_2350.field_11033) {
                    e -= 0.05D;
                    d += random.nextDouble();
                    f += random.nextDouble();
                } else {
                    e += random.nextDouble() * 0.8D;
                    if (direction.method_10166() == class_2350.class_2351.field_11048) {
                        f += random.nextDouble();
                        if (direction == class_2350.field_11034) {
                            ++d;
                        } else {
                            d += 0.05D;
                        }
                    } else {
                        d += random.nextDouble();
                        if (direction == class_2350.field_11035) {
                            ++f;
                        } else {
                            f += 0.05D;
                        }
                    }
                }

                world.method_8406(class_2398.field_11223, d, e, f, 0.0D, 0.0D, 0.0D);
            }
        }
    }

}
